@@ -2,7 +2,7 @@
 #
 #    fiksel.R
 #
-#    $Revision: 1.11 $	$Date: 2015/10/21 09:06:57 $
+#    $Revision: 1.12 $	$Date: 2016/02/16 01:39:12 $
 #
 #    Fiksel interaction 
 #    
@@ -124,7 +124,7 @@ Fiksel <- local({
          irange = function(self, coeffs=NA, epsilon=0, ...) {
            r <- self$par$r
            hc <- self$par$hc
-           if(any(is.na(coeffs)))
+           if(anyNA(coeffs))
              return(r)
            a <- coeffs[1]
            if(abs(a) <= epsilon)
