@@ -3,7 +3,7 @@
 #
 #  leverage and influence
 #
-#  $Revision: 1.47 $  $Date: 2015/12/23 08:45:13 $
+#  $Revision: 1.54 $  $Date: 2016/03/09 10:31:14 $
 #
 
 leverage <- function(model, ...) {
@@ -50,12 +50,14 @@ dfbetas.ppm <- function(model, ...,
 
 
 ppmInfluence <- function(fit,
-                          what=c("leverage", "influence", "dfbetas",
-                            "derivatives", "increments"),
-                          ..., iScore=NULL, iHessian=NULL, iArgs=NULL,
-                          drop=FALSE,
-                          method=c("C", "interpreted"),
-                          precomputed=list()) {
+                         what=c("leverage", "influence", "dfbetas",
+                                "derivatives", "increments"),
+                         ...,
+                         iScore=NULL, iHessian=NULL, iArgs=NULL,
+                         drop=FALSE,
+                         method=c("C", "interpreted"),
+                          precomputed=list(),
+                         sparseOK=FALSE) {
   stopifnot(is.ppm(fit))
   what <- match.arg(what, several.ok=TRUE)
   method <- match.arg(method)
@@ -69,13 +71,14 @@ ppmInfluence <- function(fit,
     stop("Must supply iHessian")
   if(fit$method == "logi" && !spatstat.options("allow.logi.influence"))
     stop("ppm influence measures are not yet implemented for method=logi")
+  sparse <- sparseOK && spatstat.options('developer')
   #
   # extract precomputed values if given
   theta  <- precomputed$coef   %orifnull% coef(fit)
   lam    <- precomputed$lambda %orifnull% fitted(fit, check=FALSE)
   mom    <- precomputed$mom    %orifnull% model.matrix(fit)
   # 
-  p <- length(theta)
+#  p <- length(theta)
   vc <- vcov(fit, hessian=TRUE)
   fush <- hess <- solve(vc)
   Q <- quad.ppm(fit)
@@ -85,23 +88,44 @@ ppmInfluence <- function(fit,
   # vc = solve(fush)
   #
   w <- w.quad(Q)
-  loc <- union.quad(Q)
-  isdata <- is.data(Q)
+#  loc <- union.quad(Q)
+#  isdata <- is.data(Q)
   #
   if(length(w) != length(lam))
     stop(paste("Internal error: length(w) = ", length(w),
                "!=", length(lam), "= length(lam)\n"))
-  # 
-  # second order interaction terms
-  # ddS[i,j, ] = Delta_i Delta_j S(x)
-  ddS <- NULL
-  if(!all(what == "derivatives") && !is.poisson(fit)) {
-    ddS <- deltasuffstat(fit, dataonly=FALSE)
-    if(is.null(ddS))
-      warning("Second order interaction terms are not implemented for this model; they are treated as zero")
-  }
-  #
-  # 
+
+  a <- ppmInfluenceEngine(fit      = fit,
+                          what     = what,
+                          iScore   = iScore,
+                          iHessian = iHessian,
+                          iArgs    = iArgs,
+                          drop     = drop,
+                          method   = method,
+                          sparse   = sparse,
+                          vc       = vc,
+                          fush     = fush,
+                          hess     = hess,
+                          Q        = Q,
+                          theta    = theta,
+                          lam      = lam,
+                          mom      = mom)
+  return(a)
+}
+
+ppmInfluenceEngine <-
+  function(fit, what, iScore, iHessian, iArgs,
+           drop, method, sparse,
+           vc, fush, hess,
+           Q, theta, lam, mom) {
+  gotScore <- !is.null(iScore)
+  gotHess <- !is.null(iHessian)
+  influencecalc <- any(what %in% c("leverage", "influence", "dfbetas"))
+  needHess <- gotScore && influencecalc
+  p <- length(theta)
+  w <- w.quad(Q)
+  loc <- union.quad(Q)
+  isdata <- is.data(Q)
   ## evaluate additional (`irregular') components of score
   iscoremat <- ppmDerivatives(fit, "gradient", iScore, loc, covfunargs=iArgs)
   gotScore <- !is.null(iscoremat)
@@ -114,12 +138,6 @@ ppmInfluence <- function(fit,
     mom <- cbind(mom, iscoremat)
     REG <- 1:nreg
     IRR <- nreg + 1:nirr
-    ## add extra planes of zeroes to second-order model matrix
-    ## (zero because the irregular components are part of the trend)
-    if(!is.null(ddS)) {
-      paddim <- c(dim(ddS)[1:2], nirr)
-      ddS <- abind::abind(ddS, array(0, dim=paddim), along=3)
-    }
     ## evaluate additional (`irregular') entries of Hessian
     ihessmat <- ppmDerivatives(fit, "hessian", iHessian, loc, covfunargs=iArgs)
     if(gotHess <- !is.null(ihessmat))
@@ -164,10 +182,10 @@ ppmInfluence <- function(fit,
              fush <- sumouter(mom, wlam)
              if(gotHess) {
                # integral term
-               ok <- is.finite(wlam) & apply(is.finite(ihessmat), 1, all)
+               isfin <- is.finite(wlam) & apply(is.finite(ihessmat), 1, all)
                vintegral <-
-                 if(all(ok)) wlam %*% ihessmat else
-                             wlam[ok] %*% ihessmat[ok,, drop=FALSE]
+                 if(all(isfin)) wlam %*% ihessmat else
+                             wlam[isfin] %*% ihessmat[isfin,, drop=FALSE]
                # sum over data points
                vdata <- .colSums(ihessmat[isdata, , drop=FALSE],
                                  sum(isdata), ncol(ihessmat),
@@ -191,16 +209,45 @@ ppmInfluence <- function(fit,
     invhess <- vc
   }
   #
+  ok <- NULL
   if(drop) {
     ok <- complete.cases(mom)
-    Q <- Q[ok]
-    mom <- mom[ok, , drop=FALSE]
-    loc <- loc[ok]
-    lam <- lam[ok]
-    w   <- w[ok]
-    isdata <- isdata[ok]
-    if(!is.null(ddS)) ddS <- ddS[ok, ok, , drop=FALSE]
+    if(all(ok)) {
+      ok <- NULL
+    } else {
+      Q <- Q[ok]
+      mom <- mom[ok, , drop=FALSE]
+      loc <- loc[ok]
+      lam <- lam[ok]
+      w   <- w[ok]
+      isdata <- isdata[ok]
+    }
+  } 
+  
+  # second order interaction terms
+  # ddS[i,j, ] = Delta_i Delta_j S(x)
+  ddS <- NULL
+  if(!all(what == "derivatives") && !is.poisson(fit)) {
+    ddS <- deltasuffstat(fit, dataonly=FALSE, quadsub=ok, sparseOK=sparse)
+    if(is.null(ddS)) {
+      warning("Second order interaction terms are not implemented for this model; they are treated as zero")
+    } else {
+      sparse <- inherits(ddS, "sparse3Darray")
+      if(gotScore) {
+        ## add extra planes of zeroes to second-order model matrix
+        ## (zero because the irregular components are part of the trend)
+        paddim <- c(dim(ddS)[1:2], nirr)
+        if(!sparse) {
+          ddS <- abind::abind(ddS, array(0, dim=paddim), along=3)
+        } else {
+          ddS <- bind.sparse3Darray(ddS,
+                                    sparse3Darray(dims=paddim),
+                                    along=3)
+        }
+      }
+    }
   }
+
   # ........  start assembling results .....................
   # 
   result <- list()
@@ -222,33 +269,56 @@ ppmInfluence <- function(fit,
   if(!is.poisson(fit) && !is.null(ddS)) {
     # effect of addition/deletion of U[j] on score contribution from data points
     ddSX <- ddS[isdata, , , drop=FALSE]
-    eff.data <- apply(ddSX, c(2,3), sum)
-    # check whether any quadrature points have zero conditional intensity
-    zerocif <- rep(TRUE, nrow(eff.data))
-    if(any(theta > 0)) 
-      zerocif <- apply(eff.data[, theta > 0, drop=FALSE] != -Inf, 1, any)
-    if(any(theta < 0)) 
-      zerocif <- zerocif &
-        apply(eff.data[, theta < 0, drop=FALSE] != Inf, 1, any)
-    eff.data[zerocif, ] <- 0
-    # model matrix after addition/deletion of each U[j]
-    # mombefore[i,j,] <- mom[i,]
-    di <- dim(ddS)
-    mombefore <- array(apply(mom, 2, rep, times=di[2]), dim=di)
+    eff.data <- marginSums(ddSX, c(2,3))
+    rm(ddSX)
+    gc()
+    # check if any quadrature points have zero conditional intensity;
+    # these do not contribute; the associated values of the sufficient
+    # statistic may be Infinite and must be explicitly set to zero.
+    zerocif <- (lam == 0)
+    anyzerocif <- any(zerocif)
+    if(anyzerocif)
+      eff.data[zerocif, ] <- 0 
+    ## effect of addition/deletion of U[j] on integral term in score
     changesign <- ifelse(isdata, -1, 1)
-    momchange <- ddS
-    momchange[ , isdata, ] <- - momchange[, isdata, ]
-    momafter <- mombefore + momchange
-    # effect of addition/deletion of U[j] on lambda(U[i], X)
-    lamratio <- exp(tensor::tensor(momchange[,,REG], theta, 3, 1))
-    lamratio <- array(lamratio, dim=dim(momafter))
-    # integrate 
-    ddSintegrand <- lam * (momafter * lamratio - mombefore)
-    ddSintegrand[zerocif,,] <- 0
-    ddSintegrand[,zerocif,] <- 0
-    eff.back <- changesign * tensor::tensor(ddSintegrand, w, 1, 1)
+    if(!sparse) {
+      ## model matrix after addition/deletion of each U[j]
+      ## mombefore[i,j,] <- mom[i,]
+      di <- dim(ddS)
+      mombefore <- array(apply(mom, 2, rep, times=di[2]), dim=di)
+      momchange <- ddS
+      momchange[ , isdata, ] <- - momchange[, isdata, ]
+      momafter <- mombefore + momchange
+      ## effect of addition/deletion of U[j] on lambda(U[i], X)
+      lamratio <- exp(tensor::tensor(momchange[,,REG,drop=FALSE], theta, 3, 1))
+      lamratio <- array(lamratio, dim=dim(momafter))
+      ddSintegrand <- lam * (momafter * lamratio - mombefore)
+      rm(lamratio, momchange, mombefore, momafter)
+      gc()
+    } else {
+      ## Entries are required only for pairs i,j which interact.
+      ## mombefore[i,j,] <- mom[i,]
+      mombefore <- mapSparseEntries(ddS, 1, mom, conform=TRUE, across=3)
+      momchange <- ddS
+      momchange[ , isdata, ] <- - momchange[, isdata, ]
+      momafter <- mombefore + momchange
+      ## lamarray[i,j,k] <- lam[i]
+      lamarray <- mapSparseEntries(ddS, 1, lam, conform=TRUE, across=3)
+      lamratiominus1 <- expm1(tenseur(momchange[,,REG,drop=FALSE], theta, 3, 1))
+      lamratiominus1 <- as.sparse3Darray(lamratiominus1)
+      ddSintegrand <- lamarray * (momafter * lamratiominus1 + momchange)
+      rm(lamratiominus1, lamarray, momchange, mombefore, momafter)
+      gc()
+    }
+    if(anyzerocif) {
+      ddSintegrand[zerocif,,] <- 0
+      ddSintegrand[,zerocif,] <- 0
+    }
+    ## integrate 
+    eff.back <- changesign * tenseur(ddSintegrand, w, 1, 1)
     # total
     eff <- eff + eff.data - eff.back
+    eff <- as.matrix(eff)
   } else ddSintegrand <- NULL
 
   # 
@@ -325,6 +395,17 @@ ppmInfluence <- function(fit,
   return(result)
 }
 
+## ppmInfluenceRecombine <- function(indices, values) {
+  #'  indices is a list of subset index vectors for each block
+  #'  values is a list containing the computed values for each block
+#           nblocks <- length(indices)
+  # deriv: list(mom, score, fush, vc, hess, invhess)
+  # increm: list(ddS, ddSintegrand, isdata, wQ)
+  # lev: list(val, smo, ave)
+  # infl: V
+  # dfbetas: msr(Q, dis[isdata, ], con)
+# }
+
 ## extract derivatives from covariate functions
 ## WARNING: these are not the score components in general
 
@@ -349,7 +430,7 @@ ppmDerivatives <- function(fit, what=c("gradient", "hessian"),
     return(NULL)
   switch(what,
          gradient = {
-           result <- do.call("cbind", unname(lapply(Dlist, as.data.frame)))
+           result <- do.call(cbind, unname(lapply(Dlist, as.data.frame)))
            result <- as.matrix(result)
          },
          hessian = {
@@ -365,12 +446,12 @@ plot.leverage.ppm <- function(x, ..., showcut=TRUE, col.cut=par("fg")) {
   fitname <- x$fitname
   defaultmain <- paste("Leverage for", fitname)
   y <- x$lev
-  do.call("plot.im",
+  do.call(plot.im,
           resolve.defaults(list(y$smo),
                            list(...),
                            list(main=defaultmain)))
   if(showcut && diff(range(y$smo)) != 0) 
-    do.call.matched("contour.im",
+    do.call.matched(contour.im,
                     resolve.defaults(list(x=y$smo, levels=y$ave,
                                           add=TRUE, col=col.cut),
                                      list(...),
@@ -383,7 +464,7 @@ plot.leverage.ppm <- function(x, ..., showcut=TRUE, col.cut=par("fg")) {
 plot.influence.ppm <- function(x, ...) {
   fitname <- x$fitname
   defaultmain <- paste("Influence for", fitname)
-  do.call("plot.ppp",
+  do.call(plot.ppp,
           resolve.defaults(list(x$infl),
                            list(...),
                            list(main=defaultmain)))
