@@ -5,7 +5,7 @@
 #
 #   original code by Abdollah Jalilian
 #
-#  $Revision: 1.15 $    $Date: 2015/05/13 08:59:30 $
+#  $Revision: 1.17 $    $Date: 2015/07/18 03:12:53 $
 #
 
 rLGCP <- local({
@@ -21,11 +21,6 @@ rLGCP <- local({
     if(!all(nzchar(names(param))))
       stop("Outdated syntax of argument 'param' to rLGCP", call.=FALSE)
     ## 
-    if(!isNamespaceLoaded("RandomFields"))
-      stop(paste("The package RandomFields is required:",
-                 "please type library(RandomFields)"),
-           call.=FALSE)
-    ##
     do.rLGCP(model=model, mu=mu, param=param, ...,
              win=win, saveLambda=saveLambda, nsim=nsim, drop=drop)
   }
@@ -35,6 +30,7 @@ rLGCP <- local({
                        eps = NULL, dimyx = NULL, xy = NULL,
                        modelonly=FALSE, nsim=1, drop=TRUE) {
     ## make RF model object from RandomFields package
+    kraever("RandomFields")
     ## get the 'model generator'
     modelname <- if(model == "exponential") "exp" else model
     modgen <- try(getExportedValue("RandomFields", 
