@@ -1,5 +1,5 @@
 #
-# $Id: rmh.default.R,v 1.101 2015/10/21 09:06:57 adrian Exp adrian $
+# $Id: rmh.default.R,v 1.102 2016/02/11 10:17:12 adrian Exp $
 #
 rmh.default <- function(model,start=NULL,
                         control=default.rmhcontrol(model),
@@ -486,7 +486,7 @@ rmh.default <- function(model,start=NULL,
   class(InfoList) <- c("rmhInfoList", class(InfoList))
 
   # go
-  do.call("rmhEngine",
+  do.call(rmhEngine,
           append(list(InfoList,
                       verbose=verbose, snoop=snoop, kitchensink=TRUE),
                  f.args))
@@ -745,7 +745,7 @@ rmhEngine <- function(InfoList, ...,
     
   ipar <- model$C.ipar
   iparlist <- if(ncif == 1) list(ipar) else model$C.iparlist
-  iparlen <- unlist(lapply(iparlist, length))
+  iparlen <- lengths(iparlist)
 
   beta <- model$internal$beta
   
